==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Пожалуйста, авторизуйте меня.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Добавить контакт - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Открыть окно чата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Послать сообщение</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показать vCard</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Ник</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Определить ник</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Контакт &lt;b&gt;%1&lt;/b&gt; уже существует.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* разделитель вложенных групп - &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Невозможно добавить контакт  &apos;&lt;b&gt;%1&lt;/b&gt;&apos;, т.к. он не является правильным Jabber ID</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Ник:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Группа:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Контакт:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизация</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Запросить авторизацию</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>Subscription requests</source>
        <translation>Запросы авторизации</translation>
    </message>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 хочет подписаться на ваш статус.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 отписался от вашего статуса.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>%1 удалил вашу авторизацию на получение статуса.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>В эту группу</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Создать новую...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>В корень</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизация</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Запросить</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Копировать контакт</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Переместить контакт</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Копировать группу</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Переместить группу</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Отказаться</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Копировать в группу</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Переместить в группу</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Удалить из группы</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>Удалить из контакт-листа</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Удалить группу</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Удалить контакты</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Сообщение авторизации от %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Сообщение авторизации</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Переименовать контакт</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Введите имя для: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Создать новую группу</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Введите имя группы:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Удалить контакт</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Вы уверены, что хотите удалить контакт &lt;b&gt;%1&lt;/b&gt; из контакт-листа?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Переименовать группу</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Введите новое имя группы:</translation>
    </message>
    <message>
        <source>You are assured that wish to remove %1 contact(s) from roster?</source>
        <translation>Вы уверены, что хотите удалить %1 контакт(ов) из контакт-листа?</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>%1 авторизовал вас на получение статуса.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Авторизовать контакт</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Удалить авторизацию</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>Подписаться на получение статуса контакта</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Вы уверены, что хотите подписаться на получение статуса контакта &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Отписаться от получения статуса контакта</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Вы уверены, что хотите отписаться от получения статуса контакта &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Редактор ростера</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Позволяет редактировать ростер</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Автоматически принимать запросы на авторизации</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Автоматически удалять авторизацию</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Переименовать контакт/группу</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Удалить контакт/группу из группы</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Del</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Удалить контакт/группу из списка контактов</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Добавить контакт...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Общая группа</translation>
    </message>
    <message>
        <source>Roster management</source>
        <translation>Управление контакт-листом</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Запрос авторизации - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Открыть окно чата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Послать сообщение</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показать vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Добавить пользователя в контакт-лист</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Авторизовать</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Удалить авторизацию</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Пожалуйста, авторизуйте меня.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Добавить контакт - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Открыть окно чата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Послать сообщение</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показать vCard</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Ник</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Определить ник</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Контакт &lt;b&gt;%1&lt;/b&gt; уже существует.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* разделитель вложенных групп - &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Невозможно добавить контакт  &apos;&lt;b&gt;%1&lt;/b&gt;&apos;, т.к. он не является правильным Jabber ID</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Ник:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Группа:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Контакт:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизация</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Запросить авторизацию</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 хочет подписаться на ваш статус.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 отписался от вашего статуса.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>%1 удалил вашу авторизацию на получение статуса.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>В эту группу</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Создать новую...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>В корень</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Авторизация</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Запросить</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Копировать контакт</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Переместить контакт</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Копировать группу</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Переместить группу</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Отказаться</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Копировать в группу</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Переместить в группу</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Удалить из группы</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>Удалить из контакт-листа</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Удалить группу</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Удалить контакты</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Сообщение авторизации от %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Сообщение авторизации</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Переименовать контакт</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Введите имя для: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Создать новую группу</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Введите имя группы:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Удалить контакт</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Вы уверены, что хотите удалить контакт &lt;b&gt;%1&lt;/b&gt; из контакт-листа?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Переименовать группу</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Введите новое имя группы:</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>%1 авторизовал вас на получение статуса.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Авторизовать контакт</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Удалить авторизацию</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>Подписаться на получение статуса контакта</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Вы уверены, что хотите подписаться на получение статуса контакта &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Отписаться от получения статуса контакта</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Вы уверены, что хотите отписаться от получения статуса контакта &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Редактор ростера</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Позволяет редактировать ростер</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Автоматически принимать запросы на авторизации</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Автоматически удалять авторизацию</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Переименовать контакт/группу</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Удалить контакт/группу из группы</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Del</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Удалить контакт/группу из списка контактов</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Добавить контакт...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Общая группа</translation>
    </message>
    <message>
        <source>When receiving authorization request</source>
        <translation>При получении запроса авторизации</translation>
    </message>
    <message numerus="yes">
        <source>You are assured that wish to remove &lt;b&gt;%n contact(s)&lt;/b&gt; from roster?</source>
        <translation>
            <numerusform>Вы уверены, что хотите удалить &lt;b&gt;%n контакт&lt;/b&gt; из списка контактов?</numerusform>
            <numerusform>Вы уверены, что хотите удалить &lt;b&gt;%n контакта&lt;/b&gt; из списка контактов?</numerusform>
            <numerusform>Вы уверены, что хотите удалить &lt;b&gt;%n контактов&lt;/b&gt; из списка контактов?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Запрос авторизации - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Открыть окно чата</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Послать сообщение</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Показать vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Добавить пользователя в контакт-лист</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Авторизовать</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Удалить авторизацию</translation>
    </message>
</context>
</TS>
